==> react-molecule-accordion-1.14.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["children", "defaultOpenedTabs", "onToggleTab", "withAutoClose"];
import { useState } from 'react';
import PropTypes from 'prop-types';
import Tab from './Tab';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = 'sui-MoleculeAccordion';

var MoleculeAccordion = function MoleculeAccordion(_ref) {
  var children = _ref.children,
      _ref$defaultOpenedTab = _ref.defaultOpenedTabs,
      defaultOpenedTabs = _ref$defaultOpenedTab === void 0 ? [] : _ref$defaultOpenedTab,
      _ref$onToggleTab = _ref.onToggleTab,
      onToggleTab = _ref$onToggleTab === void 0 ? function () {} : _ref$onToggleTab,
      withAutoClose = _ref.withAutoClose,
      tabProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var initialOpenTabs = children.map(function (_, index) {
    return defaultOpenedTabs.includes(index);
  });

  var _useState = useState([]),
      openTabs = _useState[0],
      setOpenTabs = _useState[1];

  var _handleOnToggle = function _handleOnToggle(index) {
    return function (event) {
      var newOpenTabs = [];

      if (withAutoClose) {
        newOpenTabs[index] = openTabs[index] ? undefined : true;
      } else {
        newOpenTabs = [].concat(openTabs);
        newOpenTabs[index] = newOpenTabs[index] ? undefined : true;
      }

      onToggleTab(event, {
        index: index,
        openTabs: [].concat(newOpenTabs)
      });
      setOpenTabs([].concat(newOpenTabs));
    };
  };

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: children.map(function (child, index) {
      var isDefaultOpenedTab = initialOpenTabs[index];
      var isCurrentOpenedTab = openTabs[index];
      return /*#__PURE__*/_jsx(Tab, _extends({
        isOpen: isDefaultOpenedTab || isCurrentOpenedTab,
        onToggle: _handleOnToggle(index),
        title: child.props.label
      }, tabProps, {
        children: child.props.children
      }), index);
    })
  });
};

MoleculeAccordion.displayName = 'MoleculeAccordion';
MoleculeAccordion.defaultProps = {
  withAutoClose: true
};
export default MoleculeAccordion;

==> react-molecule-accordion-1.16.0.tgz: package/lib/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
var _excluded = ["children", "defaultOpenedTabs", "onToggleTab", "withAutoClose"];
import { useState } from 'react';
import PropTypes from 'prop-types';
import Tab from './Tab';
import { jsx as _jsx } from "react/jsx-runtime";
var BASE_CLASS = 'sui-MoleculeAccordion';

var MoleculeAccordion = function MoleculeAccordion(_ref) {
  var children = _ref.children,
      _ref$defaultOpenedTab = _ref.defaultOpenedTabs,
      defaultOpenedTabs = _ref$defaultOpenedTab === void 0 ? [] : _ref$defaultOpenedTab,
      _ref$onToggleTab = _ref.onToggleTab,
      onToggleTab = _ref$onToggleTab === void 0 ? function () {} : _ref$onToggleTab,
      withAutoClose = _ref.withAutoClose,
      tabProps = _objectWithoutPropertiesLoose(_ref, _excluded);

  var initialOpenTabs = children.map(function (_, index) {
    return defaultOpenedTabs.includes(index);
  });

  var _useState = useState(initialOpenTabs),
      openTabs = _useState[0],
      setOpenTabs = _useState[1];

  var _handleOnToggle = function _handleOnToggle(index) {
    return function (event) {
      var newOpenTabs = [];

      if (withAutoClose) {
        newOpenTabs[index] = openTabs[index] ? undefined : true;
      } else {
        newOpenTabs = [].concat(openTabs);
        newOpenTabs[index] = newOpenTabs[index] ? undefined : true;
      }

      onToggleTab(event, {
        index: index,
        openTabs: [].concat(newOpenTabs)
      });
      setOpenTabs([].concat(newOpenTabs));
    };
  };

  return /*#__PURE__*/_jsx("div", {
    className: BASE_CLASS,
    children: children.map(function (child, index) {
      return /*#__PURE__*/_jsx(Tab, _extends({
        isOpen: !!openTabs[index],
        onToggle: _handleOnToggle(index),
        title: child.props.label
      }, tabProps, {
        children: child.props.children
      }), index);
    })
  });
};

MoleculeAccordion.displayName = 'MoleculeAccordion';
MoleculeAccordion.defaultProps = {
  withAutoClose: true
};
export default MoleculeAccordion;
